@@ -13,6 +13,9 @@ class Drum(Instrument):
 	def crash(self):
 		return [Note("C#", 3)]
 
+	def clap(self):
+		return [Note("D#", 2)]
+
 	def hihat_closed(self):
 		return [Note("G#", 2)]
 
