@@ -4,5 +4,6 @@ from BlastBeat import BlastBeat
 from Metronome import Metronome
 from Snare import Snare
 from DanceBeat import DanceBeat
+from Toms import Toms
 
-__all__ = ['RockDrum', 'JazzDrum', 'BlastBeat', 'Metronome', 'Snare', 'DanceBeat']
+__all__ = ['RockDrum', 'JazzDrum', 'BlastBeat', 'Metronome', 'Snare', 'DanceBeat', 'Toms']
